****This do file replicates all the data in Bloom, Kretschmer and Van Reenen (April 2011) SMJ
*More data is available on the world management survey website www.worldmanagementsurvey.org

cap log close
clear all
set memory 250m
set more 1

****RUN THE RESULTS USING REAL WLB DATA
cap log using ffwp_smj_final,replace t
u real_wlb_smj_data,clear

*set macros
mac def noise "gender sen1 tenurep countries day2 day3 day4 day5 timelocal  duration reli aa*  "
mac def noise1 " sen1 tenurep countries day2 day3 day4 day5 timelocal  duration reli aa*  "
mac def extras " lfirmage public"
mac def extras1 "lp lfirmage public"
mac def full "USt MNt mba mbamiss femalet ldegree ldegreemiss"
mac def alldata "if ldegree~=0. & femalet~=. & femalem~=. & zzmanagement~=. & USt~=. & MNt~=. & lindiopen9599~=. & lerner~=. & competition~=. & lp~=. & zzwlb~=."


**************************************************************
**************************************************************
*Table 1b - DESCRIPTIVE STATISTICS
**************************************************************
**************************************************************

***Column 1 - All Countries
sum zzwlb hourst hoursm hoursnm hols childt wfht switcht jobsharingt subsidt roce ls le lp lm ls_e lp_e lm_e ldegree femalet femalem zzman USt MNt lindiopen lerner competition if zzwlb~=.

***Column 2 - Germany
sum zzwlb hourst hoursm hoursnm hols childt wfht switcht jobsharingt subsidt roce ls le lp lm ls_e lp_e lm_e ldegree femalet femalem zzman USt MNt lindiopen lerner competition if zzwlb~=. & ccge==1

***Column 3 - France
sum zzwlb hourst hoursm hoursnm hols childt wfht switcht jobsharingt subsidt roce ls le lp lm ls_e lp_e lm_e ldegree femalet femalem zzman USt MNt lindiopen lerner competition if zzwlb~=. & ccfr==1

***Column 4 - UK
sum zzwlb hourst hoursm hoursnm hols childt wfht switcht jobsharingt subsidt roce ls le lp lm ls_e lp_e lm_e ldegree femalet femalem zzman USt MNt lindiopen lerner competition if zzwlb~=. & ccuk==1

***Column 5 - US
sum zzwlb hourst hoursm hoursnm hols childt wfht switcht jobsharingt subsidt roce ls le lp lm ls_e lp_e lm_e ldegree femalet femalem zzman USt MNt lindiopen lerner competition if zzwlb~=. & ccus==1

*************************************************************
*************************************************************
******TABLE 1c - CORRELATION MATRIX
*************************************************************
*************************************************************
pwcorr ldegree femalet femalem zzmanagement lindiopen* lerner competition roce ls_e lp_e lm_e le lp, star(.05)

*************************************************************
*************************************************************
******TABLE 2 - CORRELATIONS BETWEEN FFWP SCORES
*************************************************************
*************************************************************

pwcorr zzwlb zz1wlb zz2wlb wlb_factor, star(.05)

*************************************************************
*************************************************************
******TABLE 3 - FFWP AND FIRM PERFORMANCE
*************************************************************
*************************************************************

*Column 1 - Labour Productivity and FFWP
areg ls_e zzwlb ccfrance ccgermany ccuk $extras, rob  abs(sic3)

*Column 2 - FFWP and Management
areg ls_e zzwlb zzman  ccfrance ccgermany ccuk $extras , rob  abs(sic3)

*footnote condition on sample where we have lp and lm
areg ls zzwlb zzman  ccfrance ccgermany ccuk $extras if lm~=.&lp~=.  ,rob  abs(sic3)

*Column 3 - Total Factor Productivity, FFWP and Management
areg ls_e zzwlb zzman lm_e lp_e ccfrance ccgermany ccuk $extras $full if lm~=.&lp~=., rob  abs(sic3)

*footnote including le - Total Factor Productivity, FFWP and Management,EMP included
areg ls_e zzwlb zzman lm_e lp_e le ccfrance ccgermany ccuk $extras $full if lm~=.&lp~=., rob  abs(sic3)

*Column 4 - Total Factor Productivity, FFWP and Management with country-dummy interactions
areg ls_e zzwlb zzman lm_e lm_e_gr lm_e_fr lm_e_us lp_e lp_e_gr lp_e_fr lp_e_us le le_gr le_fr le_us ccfrance ccgermany ccus $extras $full if lm~=.&lp~=., rob  abs(sic3)

*Column 5 - Profits and FFWP
areg roce zzwlb le ccfrance ccgermany ccuk $extras  $noise if lm~=.&lp~=., rob  abs(sic3)

*Column 6 - Profits, FFWP and Management
areg roce  zzwlb zzman  le ccfrance ccgermany ccuk $extras  $noise if lm~=.&lp~=., rob  abs(sic3)

*Column 7 - Profits, FFWP and Management
areg roce  zzwlb zzman le lm lp ccfrance ccgermany ccuk $extras $full $noise if lm~=.&lp~=., rob  abs(sic3)

*footnote for toby with capital
areg ls zzwlb le lp ccfrance ccgermany ccuk $extras, rob  abs(sic3)

*Column 8 - Profits, FFWP and Management with country-dummy interactions
areg roce  zzwlb zzman le lm lp le_gr le_fr le_us lm_gr lm_fr lm_us lp_gr lp_fr lp_us ccfrance ccgermany ccus $extras $full $noise if lm~=.&lp~=., rob  abs(sic3)

*************************************************************
*************************************************************
******TABLE 4 - FFWP AND FIRM PERFORMANCE WITH INTERACTION TERMS
*************************************************************
*************************************************************
*LABOUR PRODUCTIVITY

*Column 1 - Labour productivity - FFWP and Management, Female Interactions
areg ls_e zzwlb zzman femalem wlb_female ccfrance ccgermany ccuk $extras $alldata, rob  abs(sic3)

*Column 2 - Labour productivity - FFWP and Management, High Female Interactions
areg ls_e zzwlb zzman femalem wlb_h_female ccfrance ccgermany ccuk $extras $alldata, rob  abs(sic3)

*Column 3 - Labour productivity - FFWP and Management, Skills Interactions
areg ls_e zzwlb zzman ldegree wlb_skills ccfrance ccgermany ccuk $extras $alldata, rob  abs(sic3)

*Column 4 - Labour productivity - FFWP and Management, High Skills Interactions
areg ls_e zzwlb zzman ldegree wlb_h_skills ccfrance ccgermany ccuk $extras $alldata, rob  abs(sic3)

*Column 5 - Labour productivity - FFWP and Management, Mgt Interactions
areg ls_e zzwlb zzman wlb_mgt ccfrance ccgermany ccuk $extras $alldata, rob  abs(sic3)

*Column 6 - Labour productivity - FFWP and Management, High Mgt Interactions
areg ls_e zzwlb zzman wlb_h_mgt ccfrance ccgermany ccuk $extras $alldata, rob  abs(sic3)

*Column 7 - Total Factor Productivity, FFWP and Management, Female Interactions
areg ls_e zzwlb zzman  femalem wlb_female lm_e lp_e   ccfrance ccgermany ccuk $extras $full $alldata, rob  abs(sic3)

*Column 8 - Total Factor Productivity, FFWP and Management, High Female Interactions
areg ls_e zzwlb zzman  femalem wlb_h_female lm_e lp_e   ccfrance ccgermany ccuk $extras $full $alldata, rob  abs(sic3)

*Column 9 - Total Factor Productivity, FFWP and Management, Skills Interactions
areg ls_e zzwlb zzman  ldegree wlb_skills lm_e lp_e   ccfrance ccgermany ccuk $extras $full $alldata, rob  abs(sic3)

*Column 10 - Total Factor Productivity, FFWP and Management, High Skills Interactions
areg ls_e zzwlb zzman  ldegree wlb_h_skills lm_e lp_e   ccfrance ccgermany ccuk $extras $full $alldata, rob  abs(sic3)

*Column 11 - Total Factor Productivity, FFWP and Management, Mgt Interactions
areg ls_e zzwlb zzman  wlb_mgt lm_e lp_e   ccfrance ccgermany ccuk $extras $full $alldata, rob  abs(sic3)

*Column 12 - Total Factor Productivity, FFWP and Management, High Mgt Interactions
areg ls_e zzwlb zzman  wlb_h_mgt lm_e lp_e   ccfrance ccgermany ccuk $extras $full $alldata, rob  abs(sic3)

*************************************************************
*************************************************************
******TABLE 5 - DETERMINANTS OF WLB PRACTICES CONDITIONING ON ALL DATA PRESENT
*************************************************************
*************************************************************
*condition on capital

*Column 1 - WLB Score and Skills
areg zzwlb ldegree  ldegreemiss ccfrance ccgermany ccuk le  $extras1 $alldata,rob  abs(sic3)


*Column 2 - WLB Score and Female Total
areg zzwlb femalet ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

*Column 3 - WLB Score and Female Managers
areg zzwlb femalem ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

*footnote - not all wmen
areg zzwlb femalem femalenm ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)  

*Column 4 - WLB Score and Management
areg zzwlb zzmanagement ccfrance ccgermany ccuk le  $extras1 $alldata,rob  abs(sic3)

*footnote robust to noise controls
areg zzwlb zzmanagement ccfrance ccgermany ccuk le  $extras1 $noise $alldata,rob  abs(sic3)

*Column 5 - WLB Score and Imports
areg zzwlb lindiopen ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

*Column 6 - WLB Score and Lerner
areg zzwlb lerner ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

*Column 7 - WLB Score and Competition. NOTE THE PAPER IS VERY SLIGHTLY DIFFERENCE DUE TO SMALL TYPOS
areg zzwlb competition* ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

*Column 8 - Kitchen Sink. NOTE THE PAPER IS VERY SLIGHTLY DIFFERENCE DUE TO SMALL TYPOS
areg zzwlb ldegree  ldegreemiss femalem zzmanagement lindiopen lerner competition* ccfrance ccgermany ccuk le  $extras1 $alldata,rob  abs(sic3)

*************************************************************
*************************************************************
******APPENDIX A1 - WLB MEASURES LOOK SENSIBLE AND LINKED TO INDIVIDUAL WLB OUTCOMES AND PRACTICES.
******NOTE THAT COEFFICIENTS IN THE PAPER SHOULD ALL BE POSITIVE NOT NEGATIVE!
*************************************************************
*************************************************************

***Column 1 - WLB outcome and our WLB z-score
areg wlbf zzwlb ccfr ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

***Column 2 -   Total hours with firm controls (note positive with firm size, but not public or age)
areg wlbf hourst ccfr ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

***Footnote -   Firm and interview noise controls
areg wlbf hourst ccuk ccus ccfr le $extras1 $noise $alldata,rob  abs(sic3)

***Column 3 -   Managerial and non-managers hours both matter
areg wlbf hoursm hoursnm ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3)
test hoursm hoursnm

***Column 4 -   Holidays
areg wlbf hols ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 

***Column 5 -   Childcare flexiblity
areg wlbf childt ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 

***Column 6 -   Childcare subsidy
areg wlbf subsidt ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 

***Column 7 -   Working from home
areg wlbf wfht ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 

***Column 7 -   Job switching
areg wlbf switcht ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 

***Column 9 -   Jobsharing
areg wlbf jobsharingt ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 

***Column 10 -  Female managers
areg wlbf femalem ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 

***Footnote -   Insignificant for female non-managers
areg wlbf femalenm ccuk ccus ccfr le $extras1 $alldata,rob  abs(sic3) 


/*check against oprobit*/
oprobit wlbf hourst ccuk ccus ccfr le $extras1 $alldata,rob 

**************************************************************
**************************************************************
*APPENDIX A2 - INDIVIDUAL MANAGEMENT PRACTICES Z-SCORES & WLB Z-SCORE
******NOTE THAT COEFFICIENTS IN THE PAPER SHOULD ALL BE POSITIVE NOT NEGATIVE AND SOME NUMBERS HAVE CHANGED SLIGHTLY!
**************************************************************
**************************************************************
***Column 0  -  Kitchen Sink regression from Table 4
areg zzwlb ldegree  ldegreemiss femalem zzmanagement lindiopen lerner competition* ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

***Column 1  -  Basic regression with operations
areg zzwlb zzoperations ldegree  ldegreemiss femalem lindiopen lerner competition* ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

***Column 2  -  Basic regression with monitoring 
areg zzwlb zzmonitoring ldegree  ldegreemiss femalem lindiopen lerner competition* ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

***Column 3  -  Basic regression with targets 
areg zzwlb zztargets ldegree  ldegreemiss femalem lindiopen lerner competition* ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

***Column 4  -  Basic regression with incentives 
areg zzwlb zzincentives ldegree  ldegreemiss femalem lindiopen lerner competition* ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)

***Column 5  -  Basic regression with individual z-scores for Management practices
areg zzwlb zzoperations zzmonitoring zztargets zzincentives ldegree  ldegreemiss femalem lindiopen lerner competition* ccfrance ccgermany ccuk le $extras1 $alldata,rob  abs(sic3)


log c


